/* 
 * CSE142, 99 Winter
 * Homework 5
 * Valentine's Day
 *
 * Author:     Tony Dal Maso
 * Student ID: 9820687
 * Section:    BC
 *	
 * STARTER PROGRAM
 *
 * To start with, your job is to figure out how this program works.
 *
 * Greeting Card Designer (Ultimate version)
 *
 *  The GP142 graphics window shows some buttons and the inside
 *  or outside (cover) of a greeting card.  The idea is that you 
 *  can design what you want to card to look like by adding and moving
 *  objects: 
 *    messages, message color and position
 *    shapes,   shape color and position
 *
 *   To place a message or a greeting, you click on an appropriate button, and 
 *   then you can click on the desired position in the card.  
 
 *	 In this starter version, you can do much less.
 *   You can change the card background, place one shape on the card,
 *   and change the shape back and forth between two possible kinds.
 */

#include "gp142.h"
#include <math.h>
#include <time.h>
	/* <time.h> is here only so that one function can be called
	to seed the random number generator.
	Put it here in your program and forget about it, 
	just in case you decide later you need to use random numbers.
	*/

#define TRUE    		1
#define FALSE   		0

/*
 * The state, or status you are in determines what happens when you click 
 * the card:
 * ADD SHAPE   -- you click the card, and a new object is placed there.
 *                You get into this mode by clicking an ADD button.
 *                After doing an ADD, you are put into SELECTED mode.
 * SELECTED    -- An object is selected. In this mode, the type 
 *                rotation applies to thecurrent object.
 */
/* Hint: you may need to add statuses when you make the program more complex.*/
#define STATUS_ADD_SHAPE     1
#define STATUS_SELECTED      2
#define STATUS_ADD_MESSAGE   3
#define STATUS_SELECT_OBJECT 4

/* Configure the appearance of the buttons on the menu bar 
 * by setting the number of pixels of button height and width
 */
#define BUTTON_HEIGHT  	35
#define BUTTON_WIDTH 	100

/*change this if you add or delete buttons*/
#define NUM_BUTTONS 	6
#define SELECTED_COLOR  RED

/* Position of the card in the window */
#define PAGE_LLX (-GP142_XMAX + BUTTON_WIDTH +60)
#define PAGE_LLY (-GP142_YMAX + 100)
#define PAGE_WIDTH (GP142_XMAX - PAGE_LLX - 80)
#define PAGE_HEIGHT (GP142_YMAX - PAGE_LLY - 50)

/* For many of the GP142 functions, a line width of
 * zero means to fill the shape being drawn.
 */
#define FILL 0
#define NOFILL 1

/* Types of objects we support.  (Perhaps not all types are used yet.)*/
#define OBJECT_NONE    0
#define OBJECT_SHAPE   1
#define OBJECT_MESSAGE 2

/*if you add new types, you may need to change this*/
#define MAX_SHAPES 4
#define FIRST_SHAPE_NUM 0

#define MAX_MESSAGES 10
#define FIRST_MESSAGE_NUM 0

/* These are the kinds of shapes we support.  You'll need to add more. */
#define SHAPE_HEART       0
#define SHAPE_STAR	      1
#define SHAPE_BALLMAN     2
#define SHAPE_TRIANGLEMAN 3

/* Types of messages */
#define MESSAGE_A 0
#define MESSAGE_B 1
#define MESSAGE_C 2
#define MESSAGE_D 3
#define MESSAGE_E 4
#define MESSAGE_F 5
#define MESSAGE_G 6
#define MESSAGE_H 7
#define MESSAGE_I 8
#define MESSAGE_J 9

#define MAX 500
/* Hint: once you understand how these shape types are used, you may decide
 * to do something similar with messages
 */

/*Possible places for mouse clicks*/
#define CLICK_BUTTON 1  /* You clicked on SOME button (doesn't say which one)*/
#define CLICK_CARD 2    /* You clicked in the card area */
#define CLICK_OUTSIDE 3	/* You clicked outside the card area, not on a button*/	


/*******************  FUNCTION PROTOTYPES **************************/

/* Drawing functions */
void DrawBlankScreen (void);
void DrawButtons(int last_button);
void DrawCard (int background_color, int status, int object_count, 
			   int object_type[], int object_num[], 
			   int object_color[], int object_x[], int object_y[]);
void DrawShape(int shape_type, int color, int bottom_x, int bottom_y);
void DrawHeart (int x, int y, int color);
void DrawStar (int x, int y, int color);
void DrawBallMan (int x, int y, int color);
void DrawTriangleMan (int x, int y, int color);

/* Message Function */
void WriteMessage (int message, int color, int bottom_x, int bottom_y);

/* Mouse click handling functions */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *status, int *object_count, int object_type[], 
					  int object_num[], int object_color[], 
					  int object_x[], int object_y[], int *current_object);

int ClassifyMouseClick(int mouse_x, int mouse_y);
void HandleButton(int x, int y, int *background_color, int *status,
				   int *object_count, int object_type, int object_num[],
				   int object_color[], int *current_object);

/* Add an object to the card. */
void AddShape(int x, int y, int *status, int *object_count, 
			   int object_type[], int object_num[], int object_color[], 
			   int object_x[], int object_y[], int *current_object);

void AddMessage(int x, int y, int *status, int *object_count, 
			   int object_type[], int object_num[], int object_color[], 
			   int object_x[], int object_y[], int *current_object);

void MoveObject(int x, int y, int *object_count, int object_x[], int object_y[]);

double distance(int mouse_x, int mouse_y, int object_x, int object_y);

void titlescreen(void);
/*****************************************************************************

     MAIN

*****************************************************************************/

/* main() has two chief purposes: to contain the important variables and 
 *initialize them, and to contain the "event loop," which constantly looks 
 *to see if an event has happened, and then processes the event by calling 
 *an appropriate function. An example of an event is a mouse click.
 */
int main(void)
{
	int quit = FALSE;              /* becomes TRUE to exit program */
	int mouse_x, mouse_y;          /* coordinates of a mouse click */
	char key_hit;                  /* which key was hit            */
	
	
	/*variables and their default values*/
	int background_color = YELLOW;
	int status = STATUS_ADD_SHAPE;
	
	/* Each object will have a number telling what kind of object it is, a color,
	 * and an x and y coordinate.  You'll need to make these into arrays so you
	 * can support more than one object.
	 */
	int object_count = 0;           /* How many objects on the page? */
	int object_type[MAX] = {OBJECT_NONE};  /* Can also be a shape           */
	int object_num[MAX];                 /* If type is shape, either 
									   heart or star                 */
	int object_color[MAX];               /* Color of object               */
	int object_x[MAX];                   /* Position of object            */
	int object_y[MAX];
	
	int current_object;
	int last_button    = -1;           /* Keep track of the last button clicked.
	                                   This would be usefull when highlighting
	                                   the last button the user clicked */

	int event; /*the most recent GP142 event*/
	
	time_t t; /*needed only when initializing a random number generator*/
	

	/*
	 * INITIALIZATIONS
	 */
	srand (time(&t));	    /* Seed the random number generator. This is 
							   something you should do if you plan to use 
							   random numbers. Leave it here in your program 
							   and forget about it.*/
	

	/* These GP142 initializations don't need to be changed */
	GP142_open();           /* Open and init the GP142 Graphics Window      */
	GP142_show_text(0);     /* Hide the text window                         */
	GP142_logging(LOG_OFF); /* Change to LOG_ON if you want it.             */
	
	GP142_clear();	        /* This will clear the window & paint it white. */
	/*titlescreen ();	*/  /* Title Screen */
	GP142_animate(ANI_RUN); /* Enable periodic events                       */
	
	
	
	
	/*
	 * The main event loop:
	 * --- ---- ----- -----
	 * wait for the next user action, such as a mouse click or keyboard
	 * keypress, or a periodic update event (allowing us to display the
	 * next frame of an animation -- not used directly in this program)
	 * and call the appropriate function to handle it.  Repeat this until 
	 * the user signals "quit".
	 */
	while (!quit) {  /*this is the famous "event loop" */
		
		/*start by redrawing everything */
		DrawBlankScreen ();
		DrawCard (background_color, status, object_count, 
			      object_type, object_num, object_color, object_x, object_y);
		DrawButtons(last_button);	  /* Show the buttons...*/ 
		
		/*Wait for something to happen */
		event = GP142_await_event(&mouse_x, &mouse_y, &key_hit);
		
		/* Something just happened.  Figure out what it was, and react 
		   appropriately. */
		switch (event) {
		case GP142_QUIT:
			quit = TRUE;           /* set flag to terminate loop           */
			break;
			
		case GP142_KBD:  /*A key was pressed */
			/*not needed for this program. Use this if user will need to 
			  hit a key. Note that scanf CANNOT be used with GP142.  If you 
			  use this, the key character value is in variable "key_hit"*/
			break;
			
		case GP142_MOUSE:
			/* A mouse click has occurred. Call the mouse handler to 
			   decide where the click was and react as needed. */
			HandleMouseClick(mouse_x, mouse_y, &background_color, &status, 
					         &object_count, object_type, 
							 object_num, object_color, 
							 object_x, object_y, &current_object);			
			break;
			
		case GP142_PERIODIC:
			/*An events has occurred simply because some time has passed,*/
			/*not currently used in the program*/		
			break;

		default:
			
			break;
			
		}  /*end switch */
		
	}  /* end event loop */
	
	
	/*
	 * WRAP-UP
	 */
	GP142_close();         /* clean up and close graphics window   */
	
	return 0;
}  /*end main */

/*****************************************************************************

     FUNCTIONS

*****************************************************************************/
/* 
 * For a blank screen just draw a white rectangle that covers the whole
 * GP142 window.
 */
void DrawBlankScreen (void) {
	int font_size = 14;

	GP142_rectangleXY (WHITE,
					-GP142_XMAX, -GP142_YMAX,
					GP142_XMAX, GP142_YMAX,
					FILL);

} /*end DrawBlankScreen */


/* 
 * Draws the buttons 
 */
void DrawButtons(int last_button)
{
/* To add buttons, you'll need to change the #defined constant NUM_BUTTONS
 * and add messages to this array.  Although we haven't covered 2-D arrays
 * yet, you should be able to play with this enough to get it going.
 * Look at course packet, page N-25, for a similar example.
 */
	char b_labels [NUM_BUTTONS][25] = {
		"Background color",
			"Next, please",
			"Object color",
			   "Add Shape",
			 "Add Message",
		   "Select Object"
	};
	
	int i, text_offset = -GP142_XMAX + 6, font_size = 12;
	int y, label_y;
	
	/* draw rectangles and labels for each button */
	for(i = 0; i < NUM_BUTTONS; i++) {
		y = GP142_YMAX - i * BUTTON_HEIGHT;
		
		GP142_rectangleXY(BLACK,
			-GP142_XMAX + 4,
			y - 2,
			-GP142_XMAX + BUTTON_WIDTH,
			y - BUTTON_HEIGHT - 2, 1);
		
		
		label_y = y - BUTTON_HEIGHT/2;
		
		if (i == last_button)
			GP142_printfXY(SELECTED_COLOR, text_offset, label_y, font_size, b_labels[i]);	
		else
			GP142_printfXY(BLACK, text_offset, label_y, font_size, b_labels[i]);	
	}	
}


/*
 * Render (draw) the page and all its contents.
 */
void DrawCard (int background_color, int status, int object_count, 
			   int object_type[], int object_num[], 
			   int object_color[], int object_x[], int object_y[])
{
	int font_size = 14;
	int i;
	
	/*
	 * Draw the background of the card.
	 */
	GP142_rectangleXY (background_color,
		PAGE_LLX, PAGE_LLY,
		PAGE_LLX+ PAGE_WIDTH, PAGE_LLY+ PAGE_HEIGHT,
		FILL);
	
	/* 
	 * Draw a shape on the card, if one currently exists.
	 */
	
	for (i=0; i < object_count; i++) {

		if ( /*(object_count == 1) && */(object_type[i] == OBJECT_SHAPE)) 
			DrawShape (object_num[i], object_color[i], object_x[i], object_y[i]);
		
		if (object_type[i] == OBJECT_MESSAGE) 
			WriteMessage (object_num[i], object_color[i], object_x[i], object_y[i]);
		
	}

	/*
	 * Write an appropriate status message below the background
	 */
	switch (status) {
	case STATUS_ADD_SHAPE:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-40, font_size,
			"Click on the card to add a shape");
		break;
	
	case STATUS_SELECTED:
		GP142_printfXY (RED, PAGE_LLX, PAGE_LLY-40, font_size-3,
			"Object selected. Click button to change shape or color.");
		break;

	case STATUS_ADD_MESSAGE:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-40, font_size,
			"Click on the card to add a message");
		break;

	case STATUS_SELECT_OBJECT:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-40, font_size,
			"Please select an object by clicking near it's origin");
		break;	
	default:
		GP142_printfXY (BLACK, PAGE_LLX, PAGE_LLY-40, font_size,
			"Status error -- notify programmer");
		break;
	} /*end switch */
	
	
} /*end DrawPage */


/*
 * Draw one shape.
 */
void DrawShape(int shape_type, int color, int bottom_x, int bottom_y) {

	switch ((shape_type - FIRST_SHAPE_NUM) % MAX_SHAPES) {
	case SHAPE_HEART:
		DrawHeart (bottom_x, bottom_y, color);
		break;
	case SHAPE_STAR:
		DrawStar (bottom_x, bottom_y, color);
		break;
	case SHAPE_BALLMAN:
		DrawBallMan (bottom_x, bottom_y, color);
		break;
	case SHAPE_TRIANGLEMAN:
		DrawTriangleMan (bottom_x, bottom_y, color);
		break;
	default:
		/* Unknown shape selected */
		break;

	} /*end switch*/

}

/* Write a message */
void WriteMessage (int message, int color, int bottom_x, int bottom_y) {
	
	int font_size = 18;
	int h = (rand () %3);

	switch ((message - FIRST_MESSAGE_NUM) % MAX_MESSAGES) {
		case MESSAGE_A:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Be My Valentine");
			break;
		case MESSAGE_B:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"E-mail Me");
			break;
		case MESSAGE_C:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Sweetheart");
			break;
		case MESSAGE_D:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Tr Lv");
			break;
		case MESSAGE_E:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Be Mine");
			break;
		case MESSAGE_F:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Muy Bonito");
			break;
		case MESSAGE_G:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Me + You");
			break;
		case MESSAGE_H:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Lindisimo");
			break;
		case MESSAGE_I:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Te Quiero");
			break;
		case MESSAGE_J:
			GP142_printfXY (color, bottom_x, bottom_y, font_size + h,
			"Happy V-Day!");
			break;
		default:
			break;
	}
}  


/*
 * Draw a heart on the card. A heart will be made by two overlapping
 * circles and a triangle.
 *
 * The pulsation is caused by adding a small, random amount to the 
 * heart height each time this function is called.
 */
#define HEART_WIDTH 35
void DrawHeart (int x, int y, int color) {

	int h = (HEART_WIDTH/2) + (rand () %4);

	GP142_circleXY (color, x - h + 5, y, h);
	GP142_circleXY (color, x + h - 5, y, h);
	GP142_triangleXY (color, x- h*2 +5, y-5,
						x + h*2 -5, y-5,
						x, y - h*2 -5, FILL);

}


/*
 * Draw a star on the card.
 *
 * We make the star twinkle by selecting the number of points randomly.  Each 
 * time it is redrawn, it is slightly different than the time before, which 
 * makes it appear to pulsate,
 */
#define STARPOINTS 5
#define STARRADIUS 40
#define PI 3.1416
void DrawStar (int x, int y, int color) {

	int sp;
	double angle;
	int x1, y1;

	sp = STARPOINTS + (rand () %3);
	for (angle = 0.0; angle < 2 * PI; angle = angle + (2*PI)/sp) {
		x1 = (int) (cos (angle) * STARRADIUS);
		y1 = (int) (sin (angle) * STARRADIUS);
		GP142_lineXY (color, x+x1, y+y1, x-x1, y-y1, 1);

	}
}

void DrawBallMan (int x, int y, int color) {

	int h = (rand () %3);
	
	/* Body */
	GP142_circleXY (color, x , y, 25);
	
	/* Draw Legs then Arms */
	GP142_circleXY (color, x -h +23 , y -25, 12);
	GP142_circleXY (color, x +h -23 , y -25, 12);
	
	GP142_circleXY (color, x + 25 , y +  h + 3, 10);
	GP142_circleXY (color, x - 25 , y -  h + 5	, 10);
	
	/* Draw Eyes */
	GP142_circleXY (WHITE, x +11 , y +11, 5);
	GP142_circleXY (WHITE, x -11 , y +11, 5);
	GP142_circleXY (BLUE , x +11 , y +11, 2);
	GP142_circleXY (BLUE , x -11 , y +11, 2);

	/* Draw Mouth */
	GP142_ovalXY (WHITE, x - 9, y - 8, x + 9, y - 11, 7 - (int)(1.5*h));
	GP142_triangleXY (WHITE, x - 12, y - 5, x - 12, y - 7, x - 4, y - 7, 3);
	GP142_triangleXY (WHITE, x + 12, y - 5, x + 12, y - 7, x + 4, y - 7, 3);

}

void DrawTriangleMan (int x, int y, int color) {

	int h = (rand () %3);
	
	/* Body */
	GP142_triangleXY (color, x, y + 25, x - 30, y - 25, x + 30, y - 25, FILL);

	/* Draw Legs then Arms */
	GP142_circleXY (color, x -h +20 , y -30, 10);
	GP142_circleXY (color, x +h -20 , y -30, 10);
	
	GP142_circleXY (color, x + 20 , y +  h + 3, 10);
	GP142_circleXY (color, x - 20 , y -  h + 5, 10);

	/* Draw Eyes */
	GP142_ovalXY (WHITE, x - 5, y + 5, x - 3, y -5, FILL);
	GP142_ovalXY (WHITE, x + 5, y + 5, x + 3, y -5, FILL);

	/* Draw Mouth */
	GP142_ovalXY (WHITE, x - 8, y -13 +h, x + 8, y -16, FILL);	

}


/*
 * Mouse clicks occur in one of three regions of interest: on buttons, 
 * on the card, or anywhere else.
 */
int  ClassifyMouseClick(int mouse_x, int mouse_y)
{
  if ((mouse_x < -GP142_XMAX + BUTTON_WIDTH) &&
      (mouse_y < GP142_YMAX) &&
      (mouse_y > (GP142_YMAX - NUM_BUTTONS*BUTTON_HEIGHT)))
    return CLICK_BUTTON;
  else if (mouse_x >= PAGE_LLX && mouse_x < PAGE_LLX + PAGE_WIDTH
	  && mouse_y >= PAGE_LLY && mouse_y < PAGE_LLY + PAGE_HEIGHT)
    return CLICK_CARD;
  else
    return CLICK_OUTSIDE;

}


/*
 * Decide where a mouse click occured, and react appropriately.
 */
void HandleMouseClick(int mouse_x, int mouse_y, int *background_color, 
					  int *status, int *object_count, int *object_type, 
					  int object_num[], int object_color[], 
					  int object_x[], int object_y[], int *current_object)
{

	int mouse_click;
	int i;
	double p1;
	double p2 = 99999.0;
	int closest_point;
	mouse_click = ClassifyMouseClick(mouse_x, mouse_y);
			
	if (mouse_click == CLICK_BUTTON) {
				
		/* A button has been clicked.  Call a function to handle it*/
		/* most of the variables passed as args will NOT change*/
		HandleButton(mouse_x, mouse_y, background_color, status, 
					object_count, *object_type, object_num, 
					object_color, current_object);
	}
	
	if (mouse_click == CLICK_CARD  && *status == STATUS_ADD_SHAPE) {
		/* Add a shape, if there isn't one already */
		AddShape(mouse_x, mouse_y, status, object_count, 
			   object_type, object_num, object_color, 
			   object_x, object_y, current_object);
	}

	if (mouse_click == CLICK_CARD  && *status == STATUS_ADD_MESSAGE) {
		/* Add a message, if there isn't one already */
		AddMessage(mouse_x, mouse_y, status, object_count, 
			   object_type, object_num, object_color, 
			   object_x, object_y, current_object);
	}


	if (mouse_click == CLICK_CARD  && *status == STATUS_SELECTED) {
		/* Move the current object */
		MoveObject(mouse_x, mouse_y, current_object, object_x, object_y);

	}

	if (mouse_click == CLICK_CARD && *status == STATUS_SELECT_OBJECT) {
		/* Have the user select an object */
		for (i = 0; i < (*object_count); i++) {
			p1 = distance(mouse_x, mouse_y, object_x[i], object_y[i]);

			if (p1 < p2 && p1 < 35) {
				p2 = p1;
			    closest_point = i;
			*current_object = closest_point;
			*status = STATUS_SELECTED;
			
			}
			p2 = 99999.0;
		}
		
	}

	/* Ignore any other mouse clicks */
}

/* 
 * Figure out which button was clicked, if any, and do the right 
 * thing.
 */
void HandleButton(int x, int y, int *background_color, int *status,
				   int *object_count, int object_type, int object_num[], 
				   int object_color[], int *current_object)
{
	int buttonNum = 0; 
	
	/* If we're outside of this area, we could not have clicked on
	* a button.
	*/
	if (x > -GP142_XMAX + BUTTON_WIDTH)  
		return ;	/*That's an error situation*/
	
					/* We know the mouse clicked in the column of buttons. Calculate
					* which one.
	*/
	buttonNum = (GP142_YMAX - y)/BUTTON_HEIGHT;	 
	
	switch(buttonNum) {
	case 0:
		/* Change the background color */
		*background_color = (*background_color + 1) % MAX_COLORS;
		break;
	case 1:
		/* Change the type of the currently selected object */
		if ( /*(object_count == 1) && */(object_type == OBJECT_SHAPE) )
			object_num[*current_object] = object_num[*current_object] + 1;
		
		if (object_type == OBJECT_MESSAGE)
			object_num[*current_object] = object_num[*current_object] + 1;
		break;
	case 2:
		object_color[*current_object] = (object_color[*current_object] +1) % MAX_COLORS;
		break;
	
	case 3:
		/* Add a shape to the screen */ 
		*status = STATUS_ADD_SHAPE;
		break;

	case 4:
		/* Add a message to the screen */
		*status = STATUS_ADD_MESSAGE;
		break;
	
	case 5:
		/* Select an object */
		*status = STATUS_SELECT_OBJECT;
		break;
				
	default:
		*status = 999;
		/*Bad news if this is ever reached! */
		break;
	}
}


/* If there's room for another shape, add it to the card. */
void AddShape(int x, int y, int *status, int *object_count, 
			   int object_type[], int object_num[], int object_color[], 
			   int object_x[], int object_y[], int *current_object)
{
				
				
		*status = STATUS_SELECTED;
		object_type[*object_count] = OBJECT_SHAPE;
		object_num[*object_count] = SHAPE_HEART;
		object_color[*object_count] = PINK;
		object_x[*object_count] = x;
		object_y[*object_count] = y;
		*current_object = *object_count;
		*object_count = *object_count + 1;
		
			
}

/* This is to add messages */
void AddMessage(int x, int y, int *status, int *object_count, 
			   int *object_type, int object_num[], int object_color[], 
			   int object_x[], int object_y[], int *current_object)
{
	*status = STATUS_SELECTED;
	object_type[*object_count]  = OBJECT_MESSAGE; 
	object_num[*object_count]   = MESSAGE_A;
	object_color[*object_count] = RED;
	object_x[*object_count]     = x;
	object_y[*object_count]     = y;
	*current_object = *object_count;
	*object_count = *object_count + 1;
	
}

void MoveObject(int x, int y, int *current_object, int object_x[], int object_y[])
{
		/**current_object = *current_object - 1; */
		object_x[*current_object] = x;
		object_y[*current_object] = y;
		/**current_object = *current_object + 1; */
			
}

/* Here is the function that finds a point's distance from the origin */ 
double distance(int mouse_x, int mouse_y, int object_x, int object_y) 
{

	int x;
	int y;

	x = mouse_x - object_x;
	y = mouse_y - object_y;

	if (x < 0) x  = -(x);
	if (x < 0) y  = -(y);


	return (sqrt ((x * x) + (y * y))  );
}

/*  

void titlescreen(void) {

	int mouse_x;
	int mouse_y;
	char key_hit;
	
	int x;
	int y;
	int	color; 
	
	x = 1;
	y = 1;
	color = BLUE;
	
	GP142_rectangleXY(BLACK, -GP142_XMAX, -GP142_YMAX, GP142_XMAX, 
                      GP142_YMAX, FILL);

	GP142_printfXY(BLUE, -GP142_XMAX + 170, GP142_YMAX - 100, 
                           45, "VALENTINES");
    GP142_printfXY(GREEN, -GP142_XMAX + 250, GP142_YMAX -130,
                           20, "DAY");
    GP142_printfXY(RED, -GP142_XMAX + 120, GP142_YMAX -200,
                           45, "CARD MAKER");
    GP142_printfXY(RED, -GP142_XMAX + 137, GP142_YMAX -250,
                           45, "Version 1.0");
    GP142_printfXY(GOLD, -GP142_XMAX + 250, GP142_YMAX -270,
                           18, "By: Tony Dal Maso");
	
	
	/* BallMan 		
	/* Body 
	GP142_circleXY (color, x , y, 50);
	
	/* Draw Legs then Arms 
	GP142_circleXY (color, x  + 46 , y -50, 24);
	GP142_circleXY (color, x  - 46 , y -50, 24);
	
	GP142_circleXY (color, x + 50 , y +  6 , 20);
	GP142_circleXY (color, x - 50 , y +  10, 20);
	
	/* Draw Eyes 
	GP142_circleXY (WHITE, x +22 , y +22, 10);
	GP142_circleXY (WHITE, x -22 , y +22, 10);
	GP142_circleXY (BLUE , x +22 , y +22, 4);
	GP142_circleXY (BLUE , x -22 , y +22, 4);

	/* Draw Mouth 
	GP142_ovalXY (WHITE, x - 18, y - 16, x + 18, y - 22, 14);
	GP142_triangleXY (WHITE, x - 24, y - 10, x - 24, y - 14, x - 8, y - 14, 6);
	GP142_triangleXY (WHITE, x + 24, y - 10, x + 24, y - 14, x + 8, y - 14, 6);

	
	GP142_await_event(&mouse_x, &mouse_y, &key_hit);
}	*/	




